Trait frame_election_provider_support::onchain::Config [−][src]
pub trait Config: Config {
type Accuracy: PerThing128;
type DataProvider: ElectionDataProvider<Self::AccountId, Self::BlockNumber>;
}Expand description
Configuration trait of OnChainSequentialPhragmen.
Note that this is similar to a pallet traits, but OnChainSequentialPhragmen is not a pallet.
WARNING: the user of this pallet must ensure that the Accuracy type will work nicely with the
normalization operation done inside seq_phragmen. See
sp_npos_elections::Assignment::try_normalize for more info.
Associated Types
type Accuracy: PerThing128
type Accuracy: PerThing128
The accuracy used to compute the election:
type DataProvider: ElectionDataProvider<Self::AccountId, Self::BlockNumber>
type DataProvider: ElectionDataProvider<Self::AccountId, Self::BlockNumber>
Something that provides the data for election.